@@ -7,6 +7,7 @@ from redis import StrictRedis
 
 monkey.patch_all()
 
+
 def load_config(name):
     """ Loads a JSON file and returns an object.
 
@@ -20,7 +21,7 @@ def load_config(name):
         return json.loads(f.read())
 
 
-__version__ = '2.2.4'
+__version__ = '2.2.5'
 
 
 class ZenIRCBot(object):
@@ -67,6 +68,29 @@ class ZenIRCBot(object):
                                                     'message': message,
                                                 }}))
 
+    def send_action(self, to, message):
+        """Sends an "ACTION" message to the specified channel(s)
+
+        :param to: A list or a string, if it is a list it will send to
+                   all the people or channels listed.
+        :param string message: The message to send.
+
+        This is a helper so you don't have to handle the JSON or the
+        envelope yourself.
+
+        """
+        if isinstance(to, basestring):
+            to = (to,)
+        for channel in to:
+            self.get_redis_client().publish('out',
+                                            json.dumps({
+                                                'version': 1,
+                                                'type': 'privmsg_action',
+                                                'data': {
+                                                    'to': channel,
+                                                    'message': message,
+                                                }}))
+
     def send_admin_message(self, message):
         """
         :param string message: The message to send.
@@ -82,8 +106,9 @@ class ZenIRCBot(object):
         pubsub = self.get_redis_client().pubsub()
         pubsub.subscribe('in')
         for msg in pubsub.listen():
-            message = json.loads(msg['data'])
-            func(message=message, *args, **kwargs)
+            if msg['type'] == 'message':
+                message = json.loads(msg['data'])
+                func(message=message, *args, **kwargs)
 
     def register_commands(self, service, commands):
         """
@@ -118,13 +143,12 @@ class ZenIRCBot(object):
                         elif message['data']['message'] == 'services':
                             self.send_privmsg(message['data']['sender'],
                                               service)
-            redis_sub = gevent.spawn(self.non_blocking_redis_subscribe,
-                                     func=registration_reply,
-                                     kwargs={'service': service,
-                                             'commands': commands})
+            gevent.spawn(self.non_blocking_redis_subscribe,
+                         func=registration_reply,
+                         kwargs={'service': service, 'commands': commands})
 
     def get_redis_client(self):
         """ Get redis client using values from instantiation time."""
         return StrictRedis(host=self.host,
                            port=self.port,
-                           db=self.db)
\ No newline at end of file
+                           db=self.db)
